
'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....cosmos.tx.v1beta1 import service_pb2 as cosmos_dot_tx_dot_v1beta1_dot_service__pb2

class ServiceStub(object):
    'Service defines a gRPC service for interacting with transactions.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.Simulate = channel.unary_unary('/cosmos.tx.v1beta1.Service/Simulate', request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateRequest.SerializeToString, response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateResponse.FromString)
        self.GetTx = channel.unary_unary('/cosmos.tx.v1beta1.Service/GetTx', request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxRequest.SerializeToString, response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxResponse.FromString)
        self.BroadcastTx = channel.unary_unary('/cosmos.tx.v1beta1.Service/BroadcastTx', request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxRequest.SerializeToString, response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxResponse.FromString)
        self.GetTxsEvent = channel.unary_unary('/cosmos.tx.v1beta1.Service/GetTxsEvent', request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventRequest.SerializeToString, response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventResponse.FromString)
        self.GetBlockWithTxs = channel.unary_unary('/cosmos.tx.v1beta1.Service/GetBlockWithTxs', request_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsRequest.SerializeToString, response_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsResponse.FromString)

class ServiceServicer(object):
    'Service defines a gRPC service for interacting with transactions.\n    '

    def Simulate(self, request, context):
        'Simulate simulates executing a transaction for estimating gas usage.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTx(self, request, context):
        'GetTx fetches a tx by hash.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BroadcastTx(self, request, context):
        'BroadcastTx broadcast transaction.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTxsEvent(self, request, context):
        'GetTxsEvent fetches txs by event.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockWithTxs(self, request, context):
        'GetBlockWithTxs fetches a block with decoded txs.\n\n        Since: cosmos-sdk 0.45.2\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_ServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'Simulate': grpc.unary_unary_rpc_method_handler(servicer.Simulate, request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateRequest.FromString, response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateResponse.SerializeToString), 'GetTx': grpc.unary_unary_rpc_method_handler(servicer.GetTx, request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxRequest.FromString, response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxResponse.SerializeToString), 'BroadcastTx': grpc.unary_unary_rpc_method_handler(servicer.BroadcastTx, request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxRequest.FromString, response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxResponse.SerializeToString), 'GetTxsEvent': grpc.unary_unary_rpc_method_handler(servicer.GetTxsEvent, request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventRequest.FromString, response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventResponse.SerializeToString), 'GetBlockWithTxs': grpc.unary_unary_rpc_method_handler(servicer.GetBlockWithTxs, request_deserializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsRequest.FromString, response_serializer=cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('cosmos.tx.v1beta1.Service', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Service(object):
    'Service defines a gRPC service for interacting with transactions.\n    '

    @staticmethod
    def Simulate(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.tx.v1beta1.Service/Simulate', cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateRequest.SerializeToString, cosmos_dot_tx_dot_v1beta1_dot_service__pb2.SimulateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTx(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.tx.v1beta1.Service/GetTx', cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxRequest.SerializeToString, cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BroadcastTx(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.tx.v1beta1.Service/BroadcastTx', cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxRequest.SerializeToString, cosmos_dot_tx_dot_v1beta1_dot_service__pb2.BroadcastTxResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTxsEvent(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.tx.v1beta1.Service/GetTxsEvent', cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventRequest.SerializeToString, cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetTxsEventResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockWithTxs(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.tx.v1beta1.Service/GetBlockWithTxs', cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsRequest.SerializeToString, cosmos_dot_tx_dot_v1beta1_dot_service__pb2.GetBlockWithTxsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ....cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&interchain_security/ccv/v1/query.proto\x12\x1ainterchain_security.ccv.v1\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto2\x07\n\x05QueryB3Z1github.com/cosmos/interchain-security/x/ccv/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'interchain_security.ccv.v1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/interchain-security/x/ccv/types'
    _QUERY._serialized_start = 144
    _QUERY._serialized_end = 151




from cosmos.feegrant.v1beta1 import feegrant_pb2 as _feegrant_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryAllowanceRequest(_message.Message):
    __slots__ = ['grantee', 'granter']
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    granter: str

    def __init__(self, granter: _Optional[str]=..., grantee: _Optional[str]=...) -> None:
        ...

class QueryAllowanceResponse(_message.Message):
    __slots__ = ['allowance']
    ALLOWANCE_FIELD_NUMBER: _ClassVar[int]
    allowance: _feegrant_pb2.Grant

    def __init__(self, allowance: _Optional[_Union[(_feegrant_pb2.Grant, _Mapping)]]=...) -> None:
        ...

class QueryAllowancesRequest(_message.Message):
    __slots__ = ['grantee', 'pagination']
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, grantee: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryAllowancesResponse(_message.Message):
    __slots__ = ['allowances', 'pagination']
    ALLOWANCES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    allowances: _containers.RepeatedCompositeFieldContainer[_feegrant_pb2.Grant]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, allowances: _Optional[_Iterable[_Union[(_feegrant_pb2.Grant, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from .....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,interchain_security/ccv/provider/v1/tx.proto\x12#interchain_security.ccv.provider.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x14gogoproto/gogo.proto\x1a\x19cosmos_proto/cosmos.proto\x1a\x19google/protobuf/any.proto"\xa3\x01\n\x14MsgAssignConsumerKey\x12\x10\n\x08chain_id\x18\x01 \x01(\t\x12)\n\rprovider_addr\x18\x02 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12D\n\x0cconsumer_key\x18\x03 \x01(\x0b2\x14.google.protobuf.AnyB\x18\xca\xb4-\x14cosmos.crypto.PubKey:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x1e\n\x1cMsgAssignConsumerKeyResponse2\x99\x01\n\x03Msg\x12\x91\x01\n\x11AssignConsumerKey\x129.interchain_security.ccv.provider.v1.MsgAssignConsumerKey\x1aA.interchain_security.ccv.provider.v1.MsgAssignConsumerKeyResponseB<Z:github.com/cosmos/interchain-security/x/ccv/provider/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'interchain_security.ccv.provider.v1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z:github.com/cosmos/interchain-security/x/ccv/provider/types'
    _MSGASSIGNCONSUMERKEY.fields_by_name['provider_addr']._options = None
    _MSGASSIGNCONSUMERKEY.fields_by_name['provider_addr']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _MSGASSIGNCONSUMERKEY.fields_by_name['consumer_key']._options = None
    _MSGASSIGNCONSUMERKEY.fields_by_name['consumer_key']._serialized_options = b'\xca\xb4-\x14cosmos.crypto.PubKey'
    _MSGASSIGNCONSUMERKEY._options = None
    _MSGASSIGNCONSUMERKEY._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _MSGASSIGNCONSUMERKEY._serialized_start = 192
    _MSGASSIGNCONSUMERKEY._serialized_end = 355
    _MSGASSIGNCONSUMERKEYRESPONSE._serialized_start = 357
    _MSGASSIGNCONSUMERKEYRESPONSE._serialized_end = 387
    _MSG._serialized_start = 390
    _MSG._serialized_end = 543




from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class NextFeeDistributionEstimate(_message.Message):
    __slots__ = ['currentHeight', 'distribution_fraction', 'lastHeight', 'nextHeight', 'toConsumer', 'toProvider', 'total']
    CURRENTHEIGHT_FIELD_NUMBER: _ClassVar[int]
    DISTRIBUTION_FRACTION_FIELD_NUMBER: _ClassVar[int]
    LASTHEIGHT_FIELD_NUMBER: _ClassVar[int]
    NEXTHEIGHT_FIELD_NUMBER: _ClassVar[int]
    TOCONSUMER_FIELD_NUMBER: _ClassVar[int]
    TOPROVIDER_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    currentHeight: int
    distribution_fraction: str
    lastHeight: int
    nextHeight: int
    toConsumer: str
    toProvider: str
    total: str

    def __init__(self, currentHeight: _Optional[int]=..., lastHeight: _Optional[int]=..., nextHeight: _Optional[int]=..., distribution_fraction: _Optional[str]=..., total: _Optional[str]=..., toProvider: _Optional[str]=..., toConsumer: _Optional[str]=...) -> None:
        ...

class QueryNextFeeDistributionEstimateRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryNextFeeDistributionEstimateResponse(_message.Message):
    __slots__ = ['data']
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: NextFeeDistributionEstimate

    def __init__(self, data: _Optional[_Union[(NextFeeDistributionEstimate, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6ibc/applications/interchain_accounts/v1/metadata.proto\x12\'ibc.applications.interchain_accounts.v1\x1a\x14gogoproto/gogo.proto"\xd1\x01\n\x08Metadata\x12\x0f\n\x07version\x18\x01 \x01(\t\x12E\n\x18controller_connection_id\x18\x02 \x01(\tB#\xf2\xde\x1f\x1fyaml:"controller_connection_id"\x129\n\x12host_connection_id\x18\x03 \x01(\tB\x1d\xf2\xde\x1f\x19yaml:"host_connection_id"\x12\x0f\n\x07address\x18\x04 \x01(\t\x12\x10\n\x08encoding\x18\x05 \x01(\t\x12\x0f\n\x07tx_type\x18\x06 \x01(\tBGZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.v1.metadata_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'ZEgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/types'
    _METADATA.fields_by_name['controller_connection_id']._options = None
    _METADATA.fields_by_name['controller_connection_id']._serialized_options = b'\xf2\xde\x1f\x1fyaml:"controller_connection_id"'
    _METADATA.fields_by_name['host_connection_id']._options = None
    _METADATA.fields_by_name['host_connection_id']._serialized_options = b'\xf2\xde\x1f\x19yaml:"host_connection_id"'
    _METADATA._serialized_start = 122
    _METADATA._serialized_end = 331




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....cosmos.bank.v1beta1 import query_pb2 as cosmos_dot_bank_dot_v1beta1_dot_query__pb2

class QueryStub(object):
    'Query defines the gRPC querier service.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.Balance = channel.unary_unary('/cosmos.bank.v1beta1.Query/Balance', request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.SerializeToString, response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.FromString)
        self.AllBalances = channel.unary_unary('/cosmos.bank.v1beta1.Query/AllBalances', request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesRequest.SerializeToString, response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesResponse.FromString)
        self.SpendableBalances = channel.unary_unary('/cosmos.bank.v1beta1.Query/SpendableBalances', request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesRequest.SerializeToString, response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesResponse.FromString)
        self.TotalSupply = channel.unary_unary('/cosmos.bank.v1beta1.Query/TotalSupply', request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyRequest.SerializeToString, response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyResponse.FromString)
        self.SupplyOf = channel.unary_unary('/cosmos.bank.v1beta1.Query/SupplyOf', request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfRequest.SerializeToString, response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfResponse.FromString)
        self.Params = channel.unary_unary('/cosmos.bank.v1beta1.Query/Params', request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString, response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString)
        self.DenomMetadata = channel.unary_unary('/cosmos.bank.v1beta1.Query/DenomMetadata', request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataRequest.SerializeToString, response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataResponse.FromString)
        self.DenomsMetadata = channel.unary_unary('/cosmos.bank.v1beta1.Query/DenomsMetadata', request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataRequest.SerializeToString, response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataResponse.FromString)

class QueryServicer(object):
    'Query defines the gRPC querier service.\n    '

    def Balance(self, request, context):
        'Balance queries the balance of a single coin for a single account.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllBalances(self, request, context):
        'AllBalances queries the balance of all coins for a single account.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SpendableBalances(self, request, context):
        'SpendableBalances queries the spenable balance of all coins for a single\n        account.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalSupply(self, request, context):
        'TotalSupply queries the total supply of all coins.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SupplyOf(self, request, context):
        'SupplyOf queries the supply of a single coin.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        'Params queries the parameters of x/bank module.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomMetadata(self, request, context):
        'DenomsMetadata queries the client metadata of a given coin denomination.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomsMetadata(self, request, context):
        'DenomsMetadata queries the client metadata for all registered coin denominations.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'Balance': grpc.unary_unary_rpc_method_handler(servicer.Balance, request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.FromString, response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.SerializeToString), 'AllBalances': grpc.unary_unary_rpc_method_handler(servicer.AllBalances, request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesRequest.FromString, response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesResponse.SerializeToString), 'SpendableBalances': grpc.unary_unary_rpc_method_handler(servicer.SpendableBalances, request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesRequest.FromString, response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesResponse.SerializeToString), 'TotalSupply': grpc.unary_unary_rpc_method_handler(servicer.TotalSupply, request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyRequest.FromString, response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyResponse.SerializeToString), 'SupplyOf': grpc.unary_unary_rpc_method_handler(servicer.SupplyOf, request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfRequest.FromString, response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfResponse.SerializeToString), 'Params': grpc.unary_unary_rpc_method_handler(servicer.Params, request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString, response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString), 'DenomMetadata': grpc.unary_unary_rpc_method_handler(servicer.DenomMetadata, request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataRequest.FromString, response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataResponse.SerializeToString), 'DenomsMetadata': grpc.unary_unary_rpc_method_handler(servicer.DenomsMetadata, request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataRequest.FromString, response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('cosmos.bank.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query defines the gRPC querier service.\n    '

    @staticmethod
    def Balance(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/Balance', cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.SerializeToString, cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AllBalances(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/AllBalances', cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesRequest.SerializeToString, cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SpendableBalances(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/SpendableBalances', cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesRequest.SerializeToString, cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalSupply(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/TotalSupply', cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyRequest.SerializeToString, cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SupplyOf(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/SupplyOf', cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfRequest.SerializeToString, cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/Params', cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString, cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomMetadata(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/DenomMetadata', cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataRequest.SerializeToString, cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomsMetadata(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/DenomsMetadata', cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataRequest.SerializeToString, cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




from google.protobuf import any_pb2 as _any_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor
TYPE_EXECUTE_TX: Type
TYPE_UNSPECIFIED: Type

class CosmosTx(_message.Message):
    __slots__ = ['messages']
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]

    def __init__(self, messages: _Optional[_Iterable[_Union[(_any_pb2.Any, _Mapping)]]]=...) -> None:
        ...

class InterchainAccountPacketData(_message.Message):
    __slots__ = ['data', 'memo', 'type']
    DATA_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    memo: str
    type: Type

    def __init__(self, type: _Optional[_Union[(Type, str)]]=..., data: _Optional[bytes]=..., memo: _Optional[str]=...) -> None:
        ...

class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/genutil/v1beta1/genesis.proto\x12\x16cosmos.genutil.v1beta1\x1a\x14gogoproto/gogo.proto"X\n\x0cGenesisState\x12H\n\x07gen_txs\x18\x01 \x03(\x0cB7\xfa\xde\x1f\x18encoding/json.RawMessage\xea\xde\x1f\x06gentxs\xf2\xde\x1f\ryaml:"gentxs"B.Z,github.com/cosmos/cosmos-sdk/x/genutil/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.genutil.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/genutil/types'
    _GENESISSTATE.fields_by_name['gen_txs']._options = None
    _GENESISSTATE.fields_by_name['gen_txs']._serialized_options = b'\xfa\xde\x1f\x18encoding/json.RawMessage\xea\xde\x1f\x06gentxs\xf2\xde\x1f\ryaml:"gentxs"'
    _GENESISSTATE._serialized_start = 86
    _GENESISSTATE._serialized_end = 174




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.gov.v1beta1 import gov_pb2 as _gov_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ['deposit_params', 'deposits', 'proposals', 'starting_proposal_id', 'tally_params', 'votes', 'voting_params']
    DEPOSITS_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PROPOSALS_FIELD_NUMBER: _ClassVar[int]
    STARTING_PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    TALLY_PARAMS_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    VOTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    deposit_params: _gov_pb2.DepositParams
    deposits: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Deposit]
    proposals: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Proposal]
    starting_proposal_id: int
    tally_params: _gov_pb2.TallyParams
    votes: _containers.RepeatedCompositeFieldContainer[_gov_pb2.Vote]
    voting_params: _gov_pb2.VotingParams

    def __init__(self, starting_proposal_id: _Optional[int]=..., deposits: _Optional[_Iterable[_Union[(_gov_pb2.Deposit, _Mapping)]]]=..., votes: _Optional[_Iterable[_Union[(_gov_pb2.Vote, _Mapping)]]]=..., proposals: _Optional[_Iterable[_Union[(_gov_pb2.Proposal, _Mapping)]]]=..., deposit_params: _Optional[_Union[(_gov_pb2.DepositParams, _Mapping)]]=..., voting_params: _Optional[_Union[(_gov_pb2.VotingParams, _Mapping)]]=..., tally_params: _Optional[_Union[(_gov_pb2.TallyParams, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from tendermint.crypto import keys_pb2 as _keys_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class AuthSigMessage(_message.Message):
    __slots__ = ['pub_key', 'sig']
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    SIG_FIELD_NUMBER: _ClassVar[int]
    pub_key: _keys_pb2.PublicKey
    sig: bytes

    def __init__(self, pub_key: _Optional[_Union[(_keys_pb2.PublicKey, _Mapping)]]=..., sig: _Optional[bytes]=...) -> None:
        ...

class Packet(_message.Message):
    __slots__ = ['packet_msg', 'packet_ping', 'packet_pong']
    PACKET_MSG_FIELD_NUMBER: _ClassVar[int]
    PACKET_PING_FIELD_NUMBER: _ClassVar[int]
    PACKET_PONG_FIELD_NUMBER: _ClassVar[int]
    packet_msg: PacketMsg
    packet_ping: PacketPing
    packet_pong: PacketPong

    def __init__(self, packet_ping: _Optional[_Union[(PacketPing, _Mapping)]]=..., packet_pong: _Optional[_Union[(PacketPong, _Mapping)]]=..., packet_msg: _Optional[_Union[(PacketMsg, _Mapping)]]=...) -> None:
        ...

class PacketMsg(_message.Message):
    __slots__ = ['channel_id', 'data', 'eof']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    EOF_FIELD_NUMBER: _ClassVar[int]
    channel_id: int
    data: bytes
    eof: bool

    def __init__(self, channel_id: _Optional[int]=..., eof: bool=..., data: _Optional[bytes]=...) -> None:
        ...

class PacketPing(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class PacketPong(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)cosmos/distribution/v1beta1/genesis.proto\x12\x1bcosmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a.cosmos/distribution/v1beta1/distribution.proto"\x91\x01\n\x15DelegatorWithdrawInfo\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x125\n\x10withdraw_address\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:"withdraw_address":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xf5\x01\n!ValidatorOutstandingRewardsRecord\x127\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12\x8c\x01\n\x13outstanding_rewards\x18\x02 \x03(\x0b2\x1c.cosmos.base.v1beta1.DecCoinBQ\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00\xf2\xde\x1f\x1ayaml:"outstanding_rewards":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xd7\x01\n$ValidatorAccumulatedCommissionRecord\x127\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12l\n\x0baccumulated\x18\x02 \x01(\x0b2;.cosmos.distribution.v1beta1.ValidatorAccumulatedCommissionB\x1a\xc8\xde\x1f\x00\xf2\xde\x1f\x12yaml:"accumulated":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xd7\x01\n ValidatorHistoricalRewardsRecord\x127\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12\x0e\n\x06period\x18\x02 \x01(\x04\x12`\n\x07rewards\x18\x03 \x01(\x0b27.cosmos.distribution.v1beta1.ValidatorHistoricalRewardsB\x16\xc8\xde\x1f\x00\xf2\xde\x1f\x0eyaml:"rewards":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xc1\x01\n\x1dValidatorCurrentRewardsRecord\x127\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12]\n\x07rewards\x18\x02 \x01(\x0b24.cosmos.distribution.v1beta1.ValidatorCurrentRewardsB\x16\xc8\xde\x1f\x00\xf2\xde\x1f\x0eyaml:"rewards":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\x82\x02\n\x1bDelegatorStartingInfoRecord\x127\n\x11delegator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"delegator_address"\x127\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12g\n\rstarting_info\x18\x03 \x01(\x0b22.cosmos.distribution.v1beta1.DelegatorStartingInfoB\x1c\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:"starting_info":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xe5\x01\n\x19ValidatorSlashEventRecord\x127\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"validator_address"\x12\x0e\n\x06height\x18\x02 \x01(\x04\x12\x0e\n\x06period\x18\x03 \x01(\x04\x12e\n\x15validator_slash_event\x18\x04 \x01(\x0b20.cosmos.distribution.v1beta1.ValidatorSlashEventB\x14\xc8\xde\x1f\x00\xf2\xde\x1f\x0cyaml:"event":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00"\xb1\t\n\x0cGenesisState\x12J\n\x06params\x18\x01 \x01(\x0b2#.cosmos.distribution.v1beta1.ParamsB\x15\xc8\xde\x1f\x00\xf2\xde\x1f\ryaml:"params"\x12O\n\x08fee_pool\x18\x02 \x01(\x0b2$.cosmos.distribution.v1beta1.FeePoolB\x17\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:"fee_pool"\x12}\n\x18delegator_withdraw_infos\x18\x03 \x03(\x0b22.cosmos.distribution.v1beta1.DelegatorWithdrawInfoB\'\xc8\xde\x1f\x00\xf2\xde\x1f\x1fyaml:"delegator_withdraw_infos"\x127\n\x11previous_proposer\x18\x04 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:"previous_proposer"\x12\x7f\n\x13outstanding_rewards\x18\x05 \x03(\x0b2>.cosmos.distribution.v1beta1.ValidatorOutstandingRewardsRecordB"\xc8\xde\x1f\x00\xf2\xde\x1f\x1ayaml:"outstanding_rewards"\x12\x9e\x01\n!validator_accumulated_commissions\x18\x06 \x03(\x0b2A.cosmos.distribution.v1beta1.ValidatorAccumulatedCommissionRecordB0\xc8\xde\x1f\x00\xf2\xde\x1f(yaml:"validator_accumulated_commissions"\x12\x90\x01\n\x1cvalidator_historical_rewards\x18\x07 \x03(\x0b2=.cosmos.distribution.v1beta1.ValidatorHistoricalRewardsRecordB+\xc8\xde\x1f\x00\xf2\xde\x1f#yaml:"validator_historical_rewards"\x12\x87\x01\n\x19validator_current_rewards\x18\x08 \x03(\x0b2:.cosmos.distribution.v1beta1.ValidatorCurrentRewardsRecordB(\xc8\xde\x1f\x00\xf2\xde\x1f yaml:"validator_current_rewards"\x12\x83\x01\n\x18delegator_starting_infos\x18\t \x03(\x0b28.cosmos.distribution.v1beta1.DelegatorStartingInfoRecordB\'\xc8\xde\x1f\x00\xf2\xde\x1f\x1fyaml:"delegator_starting_infos"\x12}\n\x16validator_slash_events\x18\n \x03(\x0b26.cosmos.distribution.v1beta1.ValidatorSlashEventRecordB%\xc8\xde\x1f\x00\xf2\xde\x1f\x1dyaml:"validator_slash_events":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00B7Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01'
    _DELEGATORWITHDRAWINFO.fields_by_name['delegator_address']._options = None
    _DELEGATORWITHDRAWINFO.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _DELEGATORWITHDRAWINFO.fields_by_name['withdraw_address']._options = None
    _DELEGATORWITHDRAWINFO.fields_by_name['withdraw_address']._serialized_options = b'\xf2\xde\x1f\x17yaml:"withdraw_address"'
    _DELEGATORWITHDRAWINFO._options = None
    _DELEGATORWITHDRAWINFO._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _VALIDATOROUTSTANDINGREWARDSRECORD.fields_by_name['validator_address']._options = None
    _VALIDATOROUTSTANDINGREWARDSRECORD.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _VALIDATOROUTSTANDINGREWARDSRECORD.fields_by_name['outstanding_rewards']._options = None
    _VALIDATOROUTSTANDINGREWARDSRECORD.fields_by_name['outstanding_rewards']._serialized_options = b'\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\xc8\xde\x1f\x00\xf2\xde\x1f\x1ayaml:"outstanding_rewards"'
    _VALIDATOROUTSTANDINGREWARDSRECORD._options = None
    _VALIDATOROUTSTANDINGREWARDSRECORD._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _VALIDATORACCUMULATEDCOMMISSIONRECORD.fields_by_name['validator_address']._options = None
    _VALIDATORACCUMULATEDCOMMISSIONRECORD.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _VALIDATORACCUMULATEDCOMMISSIONRECORD.fields_by_name['accumulated']._options = None
    _VALIDATORACCUMULATEDCOMMISSIONRECORD.fields_by_name['accumulated']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x12yaml:"accumulated"'
    _VALIDATORACCUMULATEDCOMMISSIONRECORD._options = None
    _VALIDATORACCUMULATEDCOMMISSIONRECORD._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _VALIDATORHISTORICALREWARDSRECORD.fields_by_name['validator_address']._options = None
    _VALIDATORHISTORICALREWARDSRECORD.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _VALIDATORHISTORICALREWARDSRECORD.fields_by_name['rewards']._options = None
    _VALIDATORHISTORICALREWARDSRECORD.fields_by_name['rewards']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x0eyaml:"rewards"'
    _VALIDATORHISTORICALREWARDSRECORD._options = None
    _VALIDATORHISTORICALREWARDSRECORD._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _VALIDATORCURRENTREWARDSRECORD.fields_by_name['validator_address']._options = None
    _VALIDATORCURRENTREWARDSRECORD.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _VALIDATORCURRENTREWARDSRECORD.fields_by_name['rewards']._options = None
    _VALIDATORCURRENTREWARDSRECORD.fields_by_name['rewards']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x0eyaml:"rewards"'
    _VALIDATORCURRENTREWARDSRECORD._options = None
    _VALIDATORCURRENTREWARDSRECORD._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _DELEGATORSTARTINGINFORECORD.fields_by_name['delegator_address']._options = None
    _DELEGATORSTARTINGINFORECORD.fields_by_name['delegator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"delegator_address"'
    _DELEGATORSTARTINGINFORECORD.fields_by_name['validator_address']._options = None
    _DELEGATORSTARTINGINFORECORD.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _DELEGATORSTARTINGINFORECORD.fields_by_name['starting_info']._options = None
    _DELEGATORSTARTINGINFORECORD.fields_by_name['starting_info']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:"starting_info"'
    _DELEGATORSTARTINGINFORECORD._options = None
    _DELEGATORSTARTINGINFORECORD._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _VALIDATORSLASHEVENTRECORD.fields_by_name['validator_address']._options = None
    _VALIDATORSLASHEVENTRECORD.fields_by_name['validator_address']._serialized_options = b'\xf2\xde\x1f\x18yaml:"validator_address"'
    _VALIDATORSLASHEVENTRECORD.fields_by_name['validator_slash_event']._options = None
    _VALIDATORSLASHEVENTRECORD.fields_by_name['validator_slash_event']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x0cyaml:"event"'
    _VALIDATORSLASHEVENTRECORD._options = None
    _VALIDATORSLASHEVENTRECORD._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _GENESISSTATE.fields_by_name['params']._options = None
    _GENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\ryaml:"params"'
    _GENESISSTATE.fields_by_name['fee_pool']._options = None
    _GENESISSTATE.fields_by_name['fee_pool']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:"fee_pool"'
    _GENESISSTATE.fields_by_name['delegator_withdraw_infos']._options = None
    _GENESISSTATE.fields_by_name['delegator_withdraw_infos']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x1fyaml:"delegator_withdraw_infos"'
    _GENESISSTATE.fields_by_name['previous_proposer']._options = None
    _GENESISSTATE.fields_by_name['previous_proposer']._serialized_options = b'\xf2\xde\x1f\x18yaml:"previous_proposer"'
    _GENESISSTATE.fields_by_name['outstanding_rewards']._options = None
    _GENESISSTATE.fields_by_name['outstanding_rewards']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x1ayaml:"outstanding_rewards"'
    _GENESISSTATE.fields_by_name['validator_accumulated_commissions']._options = None
    _GENESISSTATE.fields_by_name['validator_accumulated_commissions']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f(yaml:"validator_accumulated_commissions"'
    _GENESISSTATE.fields_by_name['validator_historical_rewards']._options = None
    _GENESISSTATE.fields_by_name['validator_historical_rewards']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f#yaml:"validator_historical_rewards"'
    _GENESISSTATE.fields_by_name['validator_current_rewards']._options = None
    _GENESISSTATE.fields_by_name['validator_current_rewards']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f yaml:"validator_current_rewards"'
    _GENESISSTATE.fields_by_name['delegator_starting_infos']._options = None
    _GENESISSTATE.fields_by_name['delegator_starting_infos']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x1fyaml:"delegator_starting_infos"'
    _GENESISSTATE.fields_by_name['validator_slash_events']._options = None
    _GENESISSTATE.fields_by_name['validator_slash_events']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x1dyaml:"validator_slash_events"'
    _GENESISSTATE._options = None
    _GENESISSTATE._serialized_options = b'\xe8\xa0\x1f\x00\x88\xa0\x1f\x00'
    _DELEGATORWITHDRAWINFO._serialized_start = 177
    _DELEGATORWITHDRAWINFO._serialized_end = 322
    _VALIDATOROUTSTANDINGREWARDSRECORD._serialized_start = 325
    _VALIDATOROUTSTANDINGREWARDSRECORD._serialized_end = 570
    _VALIDATORACCUMULATEDCOMMISSIONRECORD._serialized_start = 573
    _VALIDATORACCUMULATEDCOMMISSIONRECORD._serialized_end = 788
    _VALIDATORHISTORICALREWARDSRECORD._serialized_start = 791
    _VALIDATORHISTORICALREWARDSRECORD._serialized_end = 1006
    _VALIDATORCURRENTREWARDSRECORD._serialized_start = 1009
    _VALIDATORCURRENTREWARDSRECORD._serialized_end = 1202
    _DELEGATORSTARTINGINFORECORD._serialized_start = 1205
    _DELEGATORSTARTINGINFORECORD._serialized_end = 1463
    _VALIDATORSLASHEVENTRECORD._serialized_start = 1466
    _VALIDATORSLASHEVENTRECORD._serialized_end = 1695
    _GENESISSTATE._serialized_start = 1698
    _GENESISSTATE._serialized_end = 2899




from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenericAuthorization(_message.Message):
    __slots__ = ['msg']
    MSG_FIELD_NUMBER: _ClassVar[int]
    msg: str

    def __init__(self, msg: _Optional[str]=...) -> None:
        ...

class Grant(_message.Message):
    __slots__ = ['authorization', 'expiration']
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    EXPIRATION_FIELD_NUMBER: _ClassVar[int]
    authorization: _any_pb2.Any
    expiration: _timestamp_pb2.Timestamp

    def __init__(self, authorization: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., expiration: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...

class GrantAuthorization(_message.Message):
    __slots__ = ['authorization', 'expiration', 'grantee', 'granter']
    AUTHORIZATION_FIELD_NUMBER: _ClassVar[int]
    EXPIRATION_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    authorization: _any_pb2.Any
    expiration: _timestamp_pb2.Timestamp
    grantee: str
    granter: str

    def __init__(self, granter: _Optional[str]=..., grantee: _Optional[str]=..., authorization: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., expiration: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class CommitID(_message.Message):
    __slots__ = ['hash', 'version']
    HASH_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    version: int

    def __init__(self, version: _Optional[int]=..., hash: _Optional[bytes]=...) -> None:
        ...

class CommitInfo(_message.Message):
    __slots__ = ['store_infos', 'version']
    STORE_INFOS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    store_infos: _containers.RepeatedCompositeFieldContainer[StoreInfo]
    version: int

    def __init__(self, version: _Optional[int]=..., store_infos: _Optional[_Iterable[_Union[(StoreInfo, _Mapping)]]]=...) -> None:
        ...

class StoreInfo(_message.Message):
    __slots__ = ['commit_id', 'name']
    COMMIT_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    commit_id: CommitID
    name: str

    def __init__(self, name: _Optional[str]=..., commit_id: _Optional[_Union[(CommitID, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n"sentinel/subscription/v2/msg.proto\x12\x18sentinel.subscription.v2\x1a\x14gogoproto/gogo.proto"3\n\x10MsgCancelRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04B\x06\xe2\xde\x1f\x02ID"\x85\x01\n\x12MsgAllocateRequest\x12\x0b\n\x03frm\x18\x01 \x01(\t\x12\x12\n\x02id\x18\x02 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07address\x18\x03 \x01(\t\x12=\n\x05bytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00"\x13\n\x11MsgCancelResponse"\x15\n\x13MsgAllocateResponse2\xde\x01\n\nMsgService\x12d\n\tMsgCancel\x12*.sentinel.subscription.v2.MsgCancelRequest\x1a+.sentinel.subscription.v2.MsgCancelResponse\x12j\n\x0bMsgAllocate\x12,.sentinel.subscription.v2.MsgAllocateRequest\x1a-.sentinel.subscription.v2.MsgAllocateResponseB?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.msg_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _MSGCANCELREQUEST.fields_by_name['id']._options = None
    _MSGCANCELREQUEST.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _MSGALLOCATEREQUEST.fields_by_name['id']._options = None
    _MSGALLOCATEREQUEST.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _MSGALLOCATEREQUEST.fields_by_name['bytes']._options = None
    _MSGALLOCATEREQUEST.fields_by_name['bytes']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _MSGCANCELREQUEST._serialized_start = 86
    _MSGCANCELREQUEST._serialized_end = 137
    _MSGALLOCATEREQUEST._serialized_start = 140
    _MSGALLOCATEREQUEST._serialized_end = 273
    _MSGCANCELRESPONSE._serialized_start = 275
    _MSGCANCELRESPONSE._serialized_end = 294
    _MSGALLOCATERESPONSE._serialized_start = 296
    _MSGALLOCATERESPONSE._serialized_end = 317
    _MSGSERVICE._serialized_start = 320
    _MSGSERVICE._serialized_end = 542




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos.slashing.v1beta1 import slashing_pb2 as cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/slashing/v1beta1/genesis.proto\x12\x17cosmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/slashing/v1beta1/slashing.proto"\x85\x02\n\x0cGenesisState\x125\n\x06params\x18\x01 \x01(\x0b2\x1f.cosmos.slashing.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12Y\n\rsigning_infos\x18\x02 \x03(\x0b2$.cosmos.slashing.v1beta1.SigningInfoB\x1c\xf2\xde\x1f\x14yaml:"signing_infos"\xc8\xde\x1f\x00\x12c\n\rmissed_blocks\x18\x03 \x03(\x0b2..cosmos.slashing.v1beta1.ValidatorMissedBlocksB\x1c\xf2\xde\x1f\x14yaml:"missed_blocks"\xc8\xde\x1f\x00"\x94\x01\n\x0bSigningInfo\x12\x0f\n\x07address\x18\x01 \x01(\t\x12t\n\x16validator_signing_info\x18\x02 \x01(\x0b2-.cosmos.slashing.v1beta1.ValidatorSigningInfoB%\xc8\xde\x1f\x00\xf2\xde\x1f\x1dyaml:"validator_signing_info""\x83\x01\n\x15ValidatorMissedBlocks\x12\x0f\n\x07address\x18\x01 \x01(\t\x12Y\n\rmissed_blocks\x18\x02 \x03(\x0b2$.cosmos.slashing.v1beta1.MissedBlockB\x1c\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:"missed_blocks"",\n\x0bMissedBlock\x12\r\n\x05index\x18\x01 \x01(\x03\x12\x0e\n\x06missed\x18\x02 \x01(\x08B/Z-github.com/cosmos/cosmos-sdk/x/slashing/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types'
    _GENESISSTATE.fields_by_name['params']._options = None
    _GENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['signing_infos']._options = None
    _GENESISSTATE.fields_by_name['signing_infos']._serialized_options = b'\xf2\xde\x1f\x14yaml:"signing_infos"\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['missed_blocks']._options = None
    _GENESISSTATE.fields_by_name['missed_blocks']._serialized_options = b'\xf2\xde\x1f\x14yaml:"missed_blocks"\xc8\xde\x1f\x00'
    _SIGNINGINFO.fields_by_name['validator_signing_info']._options = None
    _SIGNINGINFO.fields_by_name['validator_signing_info']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x1dyaml:"validator_signing_info"'
    _VALIDATORMISSEDBLOCKS.fields_by_name['missed_blocks']._options = None
    _VALIDATORMISSEDBLOCKS.fields_by_name['missed_blocks']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:"missed_blocks"'
    _GENESISSTATE._serialized_start = 129
    _GENESISSTATE._serialized_end = 390
    _SIGNINGINFO._serialized_start = 393
    _SIGNINGINFO._serialized_end = 541
    _VALIDATORMISSEDBLOCKS._serialized_start = 544
    _VALIDATORMISSEDBLOCKS._serialized_end = 675
    _MISSEDBLOCK._serialized_start = 677
    _MISSEDBLOCK._serialized_end = 721




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from .....ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/core/channel/v1/channel.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto"\xed\x01\n\x07Channel\x12)\n\x05state\x18\x01 \x01(\x0e2\x1a.ibc.core.channel.v1.State\x12,\n\x08ordering\x18\x02 \x01(\x0e2\x1a.ibc.core.channel.v1.Order\x12=\n\x0ccounterparty\x18\x03 \x01(\x0b2!.ibc.core.channel.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x123\n\x0fconnection_hops\x18\x04 \x03(\tB\x1a\xf2\xde\x1f\x16yaml:"connection_hops"\x12\x0f\n\x07version\x18\x05 \x01(\t:\x04\x88\xa0\x1f\x00"\x9c\x02\n\x11IdentifiedChannel\x12)\n\x05state\x18\x01 \x01(\x0e2\x1a.ibc.core.channel.v1.State\x12,\n\x08ordering\x18\x02 \x01(\x0e2\x1a.ibc.core.channel.v1.Order\x12=\n\x0ccounterparty\x18\x03 \x01(\x0b2!.ibc.core.channel.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x123\n\x0fconnection_hops\x18\x04 \x03(\tB\x1a\xf2\xde\x1f\x16yaml:"connection_hops"\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x0f\n\x07port_id\x18\x06 \x01(\t\x12\x12\n\nchannel_id\x18\x07 \x01(\t:\x04\x88\xa0\x1f\x00"d\n\x0cCounterparty\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"channel_id":\x04\x88\xa0\x1f\x00"\x8e\x03\n\x06Packet\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12+\n\x0bsource_port\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:"source_port"\x121\n\x0esource_channel\x18\x03 \x01(\tB\x19\xf2\xde\x1f\x15yaml:"source_channel"\x125\n\x10destination_port\x18\x04 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:"destination_port"\x12;\n\x13destination_channel\x18\x05 \x01(\tB\x1e\xf2\xde\x1f\x1ayaml:"destination_channel"\x12\x0c\n\x04data\x18\x06 \x01(\x0c\x12Q\n\x0etimeout_height\x18\x07 \x01(\x0b2\x1a.ibc.core.client.v1.HeightB\x1d\xf2\xde\x1f\x15yaml:"timeout_height"\xc8\xde\x1f\x00\x127\n\x11timeout_timestamp\x18\x08 \x01(\x04B\x1c\xf2\xde\x1f\x18yaml:"timeout_timestamp":\x04\x88\xa0\x1f\x00"\x83\x01\n\x0bPacketState\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"port_id"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:"channel_id"\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x0c\n\x04data\x18\x04 \x01(\x0c:\x04\x88\xa0\x1f\x00"@\n\x0fAcknowledgement\x12\x10\n\x06result\x18\x15 \x01(\x0cH\x00\x12\x0f\n\x05error\x18\x16 \x01(\tH\x00B\n\n\x08response*\xb7\x01\n\x05State\x126\n\x1fSTATE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x11\x8a\x9d \rUNINITIALIZED\x12\x18\n\nSTATE_INIT\x10\x01\x1a\x08\x8a\x9d \x04INIT\x12\x1e\n\rSTATE_TRYOPEN\x10\x02\x1a\x0b\x8a\x9d \x07TRYOPEN\x12\x18\n\nSTATE_OPEN\x10\x03\x1a\x08\x8a\x9d \x04OPEN\x12\x1c\n\x0cSTATE_CLOSED\x10\x04\x1a\n\x8a\x9d \x06CLOSED\x1a\x04\x88\xa3\x1e\x00*w\n\x05Order\x12$\n\x16ORDER_NONE_UNSPECIFIED\x10\x00\x1a\x08\x8a\x9d \x04NONE\x12"\n\x0fORDER_UNORDERED\x10\x01\x1a\r\x8a\x9d \tUNORDERED\x12\x1e\n\rORDER_ORDERED\x10\x02\x1a\x0b\x8a\x9d \x07ORDERED\x1a\x04\x88\xa3\x1e\x00B;Z9github.com/cosmos/ibc-go/v3/modules/core/04-channel/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.channel_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z9github.com/cosmos/ibc-go/v3/modules/core/04-channel/types'
    _STATE._options = None
    _STATE._serialized_options = b'\x88\xa3\x1e\x00'
    _STATE.values_by_name['STATE_UNINITIALIZED_UNSPECIFIED']._options = None
    _STATE.values_by_name['STATE_UNINITIALIZED_UNSPECIFIED']._serialized_options = b'\x8a\x9d \rUNINITIALIZED'
    _STATE.values_by_name['STATE_INIT']._options = None
    _STATE.values_by_name['STATE_INIT']._serialized_options = b'\x8a\x9d \x04INIT'
    _STATE.values_by_name['STATE_TRYOPEN']._options = None
    _STATE.values_by_name['STATE_TRYOPEN']._serialized_options = b'\x8a\x9d \x07TRYOPEN'
    _STATE.values_by_name['STATE_OPEN']._options = None
    _STATE.values_by_name['STATE_OPEN']._serialized_options = b'\x8a\x9d \x04OPEN'
    _STATE.values_by_name['STATE_CLOSED']._options = None
    _STATE.values_by_name['STATE_CLOSED']._serialized_options = b'\x8a\x9d \x06CLOSED'
    _ORDER._options = None
    _ORDER._serialized_options = b'\x88\xa3\x1e\x00'
    _ORDER.values_by_name['ORDER_NONE_UNSPECIFIED']._options = None
    _ORDER.values_by_name['ORDER_NONE_UNSPECIFIED']._serialized_options = b'\x8a\x9d \x04NONE'
    _ORDER.values_by_name['ORDER_UNORDERED']._options = None
    _ORDER.values_by_name['ORDER_UNORDERED']._serialized_options = b'\x8a\x9d \tUNORDERED'
    _ORDER.values_by_name['ORDER_ORDERED']._options = None
    _ORDER.values_by_name['ORDER_ORDERED']._serialized_options = b'\x8a\x9d \x07ORDERED'
    _CHANNEL.fields_by_name['counterparty']._options = None
    _CHANNEL.fields_by_name['counterparty']._serialized_options = b'\xc8\xde\x1f\x00'
    _CHANNEL.fields_by_name['connection_hops']._options = None
    _CHANNEL.fields_by_name['connection_hops']._serialized_options = b'\xf2\xde\x1f\x16yaml:"connection_hops"'
    _CHANNEL._options = None
    _CHANNEL._serialized_options = b'\x88\xa0\x1f\x00'
    _IDENTIFIEDCHANNEL.fields_by_name['counterparty']._options = None
    _IDENTIFIEDCHANNEL.fields_by_name['counterparty']._serialized_options = b'\xc8\xde\x1f\x00'
    _IDENTIFIEDCHANNEL.fields_by_name['connection_hops']._options = None
    _IDENTIFIEDCHANNEL.fields_by_name['connection_hops']._serialized_options = b'\xf2\xde\x1f\x16yaml:"connection_hops"'
    _IDENTIFIEDCHANNEL._options = None
    _IDENTIFIEDCHANNEL._serialized_options = b'\x88\xa0\x1f\x00'
    _COUNTERPARTY.fields_by_name['port_id']._options = None
    _COUNTERPARTY.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _COUNTERPARTY.fields_by_name['channel_id']._options = None
    _COUNTERPARTY.fields_by_name['channel_id']._serialized_options = b'\xf2\xde\x1f\x11yaml:"channel_id"'
    _COUNTERPARTY._options = None
    _COUNTERPARTY._serialized_options = b'\x88\xa0\x1f\x00'
    _PACKET.fields_by_name['source_port']._options = None
    _PACKET.fields_by_name['source_port']._serialized_options = b'\xf2\xde\x1f\x12yaml:"source_port"'
    _PACKET.fields_by_name['source_channel']._options = None
    _PACKET.fields_by_name['source_channel']._serialized_options = b'\xf2\xde\x1f\x15yaml:"source_channel"'
    _PACKET.fields_by_name['destination_port']._options = None
    _PACKET.fields_by_name['destination_port']._serialized_options = b'\xf2\xde\x1f\x17yaml:"destination_port"'
    _PACKET.fields_by_name['destination_channel']._options = None
    _PACKET.fields_by_name['destination_channel']._serialized_options = b'\xf2\xde\x1f\x1ayaml:"destination_channel"'
    _PACKET.fields_by_name['timeout_height']._options = None
    _PACKET.fields_by_name['timeout_height']._serialized_options = b'\xf2\xde\x1f\x15yaml:"timeout_height"\xc8\xde\x1f\x00'
    _PACKET.fields_by_name['timeout_timestamp']._options = None
    _PACKET.fields_by_name['timeout_timestamp']._serialized_options = b'\xf2\xde\x1f\x18yaml:"timeout_timestamp"'
    _PACKET._options = None
    _PACKET._serialized_options = b'\x88\xa0\x1f\x00'
    _PACKETSTATE.fields_by_name['port_id']._options = None
    _PACKETSTATE.fields_by_name['port_id']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"port_id"'
    _PACKETSTATE.fields_by_name['channel_id']._options = None
    _PACKETSTATE.fields_by_name['channel_id']._serialized_options = b'\xf2\xde\x1f\x11yaml:"channel_id"'
    _PACKETSTATE._options = None
    _PACKETSTATE._serialized_options = b'\x88\xa0\x1f\x00'
    _STATE._serialized_start = 1344
    _STATE._serialized_end = 1527
    _ORDER._serialized_start = 1529
    _ORDER._serialized_end = 1648
    _CHANNEL._serialized_start = 114
    _CHANNEL._serialized_end = 351
    _IDENTIFIEDCHANNEL._serialized_start = 354
    _IDENTIFIEDCHANNEL._serialized_end = 638
    _COUNTERPARTY._serialized_start = 640
    _COUNTERPARTY._serialized_end = 740
    _PACKET._serialized_start = 743
    _PACKET._serialized_end = 1141
    _PACKETSTATE._serialized_start = 1144
    _PACKETSTATE._serialized_end = 1275
    _ACKNOWLEDGEMENT._serialized_start = 1277
    _ACKNOWLEDGEMENT._serialized_end = 1341




'Client and server classes corresponding to protobuf-defined services.'
import grpc

class QueryStub(object):
    'Query defines the gRPC querier service.\n    this line is used by starport scaffolding # 2\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '

class QueryServicer(object):
    'Query defines the gRPC querier service.\n    this line is used by starport scaffolding # 2\n    '

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {}
    generic_handler = grpc.method_handlers_generic_handler('interchain_security.ccv.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query defines the gRPC querier service.\n    this line is used by starport scaffolding # 2\n    '




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ......gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCibc/applications/interchain_accounts/controller/v1/controller.proto\x122ibc.applications.interchain_accounts.controller.v1\x1a\x14gogoproto/gogo.proto"C\n\x06Params\x129\n\x12controller_enabled\x18\x01 \x01(\x08B\x1d\xf2\xde\x1f\x19yaml:"controller_enabled"BRZPgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/controller/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.controller_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'ZPgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/controller/types'
    _PARAMS.fields_by_name['controller_enabled']._options = None
    _PARAMS.fields_by_name['controller_enabled']._serialized_options = b'\xf2\xde\x1f\x19yaml:"controller_enabled"'
    _PARAMS._serialized_start = 145
    _PARAMS._serialized_end = 212




from gogoproto import gogo_pb2 as _gogo_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class EventCreateSubscription(_message.Message):
    __slots__ = ['id', 'node_address']
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    id: int
    node_address: str

    def __init__(self, id: _Optional[int]=..., node_address: _Optional[str]=...) -> None:
        ...

class EventRegister(_message.Message):
    __slots__ = ['address']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str

    def __init__(self, address: _Optional[str]=...) -> None:
        ...

class EventUpdateDetails(_message.Message):
    __slots__ = ['address']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str

    def __init__(self, address: _Optional[str]=...) -> None:
        ...

class EventUpdateStatus(_message.Message):
    __slots__ = ['address', 'status']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    address: str
    status: _status_pb2.Status

    def __init__(self, address: _Optional[str]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=...) -> None:
        ...




from cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Payout(_message.Message):
    __slots__ = ['address', 'hours', 'id', 'node_address', 'price', 'timestamp']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    HOURS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NODE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    address: str
    hours: int
    id: int
    node_address: str
    price: _coin_pb2.Coin
    timestamp: _timestamp_pb2.Timestamp

    def __init__(self, id: _Optional[int]=..., address: _Optional[str]=..., node_address: _Optional[str]=..., hours: _Optional[int]=..., price: _Optional[_Union[(_coin_pb2.Coin, _Mapping)]]=..., timestamp: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...




from ibc.core.client.v1 import client_pb2 as _client_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from ibc.core.channel.v1 import channel_pb2 as _channel_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import any_pb2 as _any_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryChannelClientStateRequest(_message.Message):
    __slots__ = ['channel_id', 'port_id']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    port_id: str

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=...) -> None:
        ...

class QueryChannelClientStateResponse(_message.Message):
    __slots__ = ['identified_client_state', 'proof', 'proof_height']
    IDENTIFIED_CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    identified_client_state: _client_pb2.IdentifiedClientState
    proof: bytes
    proof_height: _client_pb2.Height

    def __init__(self, identified_client_state: _Optional[_Union[(_client_pb2.IdentifiedClientState, _Mapping)]]=..., proof: _Optional[bytes]=..., proof_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryChannelConsensusStateRequest(_message.Message):
    __slots__ = ['channel_id', 'port_id', 'revision_height', 'revision_number']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    REVISION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    REVISION_NUMBER_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    port_id: str
    revision_height: int
    revision_number: int

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=..., revision_number: _Optional[int]=..., revision_height: _Optional[int]=...) -> None:
        ...

class QueryChannelConsensusStateResponse(_message.Message):
    __slots__ = ['client_id', 'consensus_state', 'proof', 'proof_height']
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_STATE_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    consensus_state: _any_pb2.Any
    proof: bytes
    proof_height: _client_pb2.Height

    def __init__(self, consensus_state: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=..., client_id: _Optional[str]=..., proof: _Optional[bytes]=..., proof_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryChannelRequest(_message.Message):
    __slots__ = ['channel_id', 'port_id']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    port_id: str

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=...) -> None:
        ...

class QueryChannelResponse(_message.Message):
    __slots__ = ['channel', 'proof', 'proof_height']
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    channel: _channel_pb2.Channel
    proof: bytes
    proof_height: _client_pb2.Height

    def __init__(self, channel: _Optional[_Union[(_channel_pb2.Channel, _Mapping)]]=..., proof: _Optional[bytes]=..., proof_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryChannelsRequest(_message.Message):
    __slots__ = ['pagination']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest

    def __init__(self, pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryChannelsResponse(_message.Message):
    __slots__ = ['channels', 'height', 'pagination']
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    channels: _containers.RepeatedCompositeFieldContainer[_channel_pb2.IdentifiedChannel]
    height: _client_pb2.Height
    pagination: _pagination_pb2.PageResponse

    def __init__(self, channels: _Optional[_Iterable[_Union[(_channel_pb2.IdentifiedChannel, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=..., height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryConnectionChannelsRequest(_message.Message):
    __slots__ = ['connection', 'pagination']
    CONNECTION_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    connection: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, connection: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryConnectionChannelsResponse(_message.Message):
    __slots__ = ['channels', 'height', 'pagination']
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    channels: _containers.RepeatedCompositeFieldContainer[_channel_pb2.IdentifiedChannel]
    height: _client_pb2.Height
    pagination: _pagination_pb2.PageResponse

    def __init__(self, channels: _Optional[_Iterable[_Union[(_channel_pb2.IdentifiedChannel, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=..., height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryNextSequenceReceiveRequest(_message.Message):
    __slots__ = ['channel_id', 'port_id']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    port_id: str

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=...) -> None:
        ...

class QueryNextSequenceReceiveResponse(_message.Message):
    __slots__ = ['next_sequence_receive', 'proof', 'proof_height']
    NEXT_SEQUENCE_RECEIVE_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    next_sequence_receive: int
    proof: bytes
    proof_height: _client_pb2.Height

    def __init__(self, next_sequence_receive: _Optional[int]=..., proof: _Optional[bytes]=..., proof_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryPacketAcknowledgementRequest(_message.Message):
    __slots__ = ['channel_id', 'port_id', 'sequence']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    port_id: str
    sequence: int

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=..., sequence: _Optional[int]=...) -> None:
        ...

class QueryPacketAcknowledgementResponse(_message.Message):
    __slots__ = ['acknowledgement', 'proof', 'proof_height']
    ACKNOWLEDGEMENT_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    acknowledgement: bytes
    proof: bytes
    proof_height: _client_pb2.Height

    def __init__(self, acknowledgement: _Optional[bytes]=..., proof: _Optional[bytes]=..., proof_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryPacketAcknowledgementsRequest(_message.Message):
    __slots__ = ['channel_id', 'packet_commitment_sequences', 'pagination', 'port_id']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PACKET_COMMITMENT_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    packet_commitment_sequences: _containers.RepeatedScalarFieldContainer[int]
    pagination: _pagination_pb2.PageRequest
    port_id: str

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=..., packet_commitment_sequences: _Optional[_Iterable[int]]=...) -> None:
        ...

class QueryPacketAcknowledgementsResponse(_message.Message):
    __slots__ = ['acknowledgements', 'height', 'pagination']
    ACKNOWLEDGEMENTS_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    acknowledgements: _containers.RepeatedCompositeFieldContainer[_channel_pb2.PacketState]
    height: _client_pb2.Height
    pagination: _pagination_pb2.PageResponse

    def __init__(self, acknowledgements: _Optional[_Iterable[_Union[(_channel_pb2.PacketState, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=..., height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryPacketCommitmentRequest(_message.Message):
    __slots__ = ['channel_id', 'port_id', 'sequence']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    port_id: str
    sequence: int

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=..., sequence: _Optional[int]=...) -> None:
        ...

class QueryPacketCommitmentResponse(_message.Message):
    __slots__ = ['commitment', 'proof', 'proof_height']
    COMMITMENT_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    commitment: bytes
    proof: bytes
    proof_height: _client_pb2.Height

    def __init__(self, commitment: _Optional[bytes]=..., proof: _Optional[bytes]=..., proof_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryPacketCommitmentsRequest(_message.Message):
    __slots__ = ['channel_id', 'pagination', 'port_id']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    pagination: _pagination_pb2.PageRequest
    port_id: str

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryPacketCommitmentsResponse(_message.Message):
    __slots__ = ['commitments', 'height', 'pagination']
    COMMITMENTS_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    commitments: _containers.RepeatedCompositeFieldContainer[_channel_pb2.PacketState]
    height: _client_pb2.Height
    pagination: _pagination_pb2.PageResponse

    def __init__(self, commitments: _Optional[_Iterable[_Union[(_channel_pb2.PacketState, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=..., height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryPacketReceiptRequest(_message.Message):
    __slots__ = ['channel_id', 'port_id', 'sequence']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    port_id: str
    sequence: int

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=..., sequence: _Optional[int]=...) -> None:
        ...

class QueryPacketReceiptResponse(_message.Message):
    __slots__ = ['proof', 'proof_height', 'received']
    PROOF_FIELD_NUMBER: _ClassVar[int]
    PROOF_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    RECEIVED_FIELD_NUMBER: _ClassVar[int]
    proof: bytes
    proof_height: _client_pb2.Height
    received: bool

    def __init__(self, received: bool=..., proof: _Optional[bytes]=..., proof_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryUnreceivedAcksRequest(_message.Message):
    __slots__ = ['channel_id', 'packet_ack_sequences', 'port_id']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PACKET_ACK_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    packet_ack_sequences: _containers.RepeatedScalarFieldContainer[int]
    port_id: str

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=..., packet_ack_sequences: _Optional[_Iterable[int]]=...) -> None:
        ...

class QueryUnreceivedAcksResponse(_message.Message):
    __slots__ = ['height', 'sequences']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    height: _client_pb2.Height
    sequences: _containers.RepeatedScalarFieldContainer[int]

    def __init__(self, sequences: _Optional[_Iterable[int]]=..., height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...

class QueryUnreceivedPacketsRequest(_message.Message):
    __slots__ = ['channel_id', 'packet_commitment_sequences', 'port_id']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PACKET_COMMITMENT_SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    packet_commitment_sequences: _containers.RepeatedScalarFieldContainer[int]
    port_id: str

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=..., packet_commitment_sequences: _Optional[_Iterable[int]]=...) -> None:
        ...

class QueryUnreceivedPacketsResponse(_message.Message):
    __slots__ = ['height', 'sequences']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    SEQUENCES_FIELD_NUMBER: _ClassVar[int]
    height: _client_pb2.Height
    sequences: _containers.RepeatedScalarFieldContainer[int]

    def __init__(self, sequences: _Optional[_Iterable[int]]=..., height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ......ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as ibc_dot_applications_dot_interchain__accounts_dot_controller_dot_v1_dot_controller__pb2
from ......google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>ibc/applications/interchain_accounts/controller/v1/query.proto\x122ibc.applications.interchain_accounts.controller.v1\x1aCibc/applications/interchain_accounts/controller/v1/controller.proto\x1a\x1cgoogle/api/annotations.proto"\x14\n\x12QueryParamsRequest"a\n\x13QueryParamsResponse\x12J\n\x06params\x18\x01 \x01(\x0b2:.ibc.applications.interchain_accounts.controller.v1.Params2\xdf\x01\n\x05Query\x12\xd5\x01\n\x06Params\x12F.ibc.applications.interchain_accounts.controller.v1.QueryParamsRequest\x1aG.ibc.applications.interchain_accounts.controller.v1.QueryParamsResponse":\x82\xd3\xe4\x93\x024\x122/ibc/apps/interchain_accounts/controller/v1/paramsBRZPgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/controller/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.query_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'ZPgithub.com/cosmos/ibc-go/v3/modules/apps/27-interchain-accounts/controller/types'
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\x82\xd3\xe4\x93\x024\x122/ibc/apps/interchain_accounts/controller/v1/params'
    _QUERYPARAMSREQUEST._serialized_start = 217
    _QUERYPARAMSREQUEST._serialized_end = 237
    _QUERYPARAMSRESPONSE._serialized_start = 239
    _QUERYPARAMSRESPONSE._serialized_end = 336
    _QUERY._serialized_start = 339
    _QUERY._serialized_end = 562




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....sentinel.plan.v2 import plan_pb2 as sentinel_dot_plan_dot_v2_dot_plan__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1esentinel/plan/v2/genesis.proto\x12\x10sentinel.plan.v2\x1a\x14gogoproto/gogo.proto\x1a\x1bsentinel/plan/v2/plan.proto"H\n\x0bGenesisPlan\x12*\n\x04plan\x18\x01 \x01(\x0b2\x16.sentinel.plan.v2.PlanB\x04\xc8\xde\x1f\x00\x12\r\n\x05nodes\x18\x02 \x03(\tB7Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.plan.v2.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/plan/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _GENESISPLAN.fields_by_name['plan']._options = None
    _GENESISPLAN.fields_by_name['plan']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISPLAN._serialized_start = 103
    _GENESISPLAN._serialized_end = 175




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class Provider(_message.Message):
    __slots__ = ['address', 'description', 'identity', 'name', 'status', 'status_at', 'website']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    WEBSITE_FIELD_NUMBER: _ClassVar[int]
    address: str
    description: str
    identity: str
    name: str
    status: _status_pb2.Status
    status_at: _timestamp_pb2.Timestamp
    website: str

    def __init__(self, address: _Optional[str]=..., name: _Optional[str]=..., identity: _Optional[str]=..., website: _Optional[str]=..., description: _Optional[str]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=..., status_at: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=...) -> None:
        ...




from google.api import annotations_pb2 as _annotations_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class MsgAssignConsumerKey(_message.Message):
    __slots__ = ['chain_id', 'consumer_key', 'provider_addr']
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    CONSUMER_KEY_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_ADDR_FIELD_NUMBER: _ClassVar[int]
    chain_id: str
    consumer_key: _any_pb2.Any
    provider_addr: str

    def __init__(self, chain_id: _Optional[str]=..., provider_addr: _Optional[str]=..., consumer_key: _Optional[_Union[(_any_pb2.Any, _Mapping)]]=...) -> None:
        ...

class MsgAssignConsumerKeyResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from tendermint.abci import types_pb2 as _types_pb2
from tendermint.types import types_pb2 as _types_pb2_1
from tendermint.types import validator_pb2 as _validator_pb2
from tendermint.types import params_pb2 as _params_pb2
from tendermint.version import types_pb2 as _types_pb2_1_1
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class ABCIResponses(_message.Message):
    __slots__ = ['begin_block', 'deliver_txs', 'end_block']
    BEGIN_BLOCK_FIELD_NUMBER: _ClassVar[int]
    DELIVER_TXS_FIELD_NUMBER: _ClassVar[int]
    END_BLOCK_FIELD_NUMBER: _ClassVar[int]
    begin_block: _types_pb2.ResponseBeginBlock
    deliver_txs: _containers.RepeatedCompositeFieldContainer[_types_pb2.ResponseDeliverTx]
    end_block: _types_pb2.ResponseEndBlock

    def __init__(self, deliver_txs: _Optional[_Iterable[_Union[(_types_pb2.ResponseDeliverTx, _Mapping)]]]=..., end_block: _Optional[_Union[(_types_pb2.ResponseEndBlock, _Mapping)]]=..., begin_block: _Optional[_Union[(_types_pb2.ResponseBeginBlock, _Mapping)]]=...) -> None:
        ...

class ConsensusParamsInfo(_message.Message):
    __slots__ = ['consensus_params', 'last_height_changed']
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    LAST_HEIGHT_CHANGED_FIELD_NUMBER: _ClassVar[int]
    consensus_params: _params_pb2.ConsensusParams
    last_height_changed: int

    def __init__(self, consensus_params: _Optional[_Union[(_params_pb2.ConsensusParams, _Mapping)]]=..., last_height_changed: _Optional[int]=...) -> None:
        ...

class State(_message.Message):
    __slots__ = ['app_hash', 'chain_id', 'consensus_params', 'initial_height', 'last_block_height', 'last_block_id', 'last_block_time', 'last_height_consensus_params_changed', 'last_height_validators_changed', 'last_results_hash', 'last_validators', 'next_validators', 'validators', 'version']
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    INITIAL_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    LAST_HEIGHT_CONSENSUS_PARAMS_CHANGED_FIELD_NUMBER: _ClassVar[int]
    LAST_HEIGHT_VALIDATORS_CHANGED_FIELD_NUMBER: _ClassVar[int]
    LAST_RESULTS_HASH_FIELD_NUMBER: _ClassVar[int]
    LAST_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    app_hash: bytes
    chain_id: str
    consensus_params: _params_pb2.ConsensusParams
    initial_height: int
    last_block_height: int
    last_block_id: _types_pb2_1.BlockID
    last_block_time: _timestamp_pb2.Timestamp
    last_height_consensus_params_changed: int
    last_height_validators_changed: int
    last_results_hash: bytes
    last_validators: _validator_pb2.ValidatorSet
    next_validators: _validator_pb2.ValidatorSet
    validators: _validator_pb2.ValidatorSet
    version: Version

    def __init__(self, version: _Optional[_Union[(Version, _Mapping)]]=..., chain_id: _Optional[str]=..., initial_height: _Optional[int]=..., last_block_height: _Optional[int]=..., last_block_id: _Optional[_Union[(_types_pb2_1.BlockID, _Mapping)]]=..., last_block_time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., next_validators: _Optional[_Union[(_validator_pb2.ValidatorSet, _Mapping)]]=..., validators: _Optional[_Union[(_validator_pb2.ValidatorSet, _Mapping)]]=..., last_validators: _Optional[_Union[(_validator_pb2.ValidatorSet, _Mapping)]]=..., last_height_validators_changed: _Optional[int]=..., consensus_params: _Optional[_Union[(_params_pb2.ConsensusParams, _Mapping)]]=..., last_height_consensus_params_changed: _Optional[int]=..., last_results_hash: _Optional[bytes]=..., app_hash: _Optional[bytes]=...) -> None:
        ...

class ValidatorsInfo(_message.Message):
    __slots__ = ['last_height_changed', 'validator_set']
    LAST_HEIGHT_CHANGED_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SET_FIELD_NUMBER: _ClassVar[int]
    last_height_changed: int
    validator_set: _validator_pb2.ValidatorSet

    def __init__(self, validator_set: _Optional[_Union[(_validator_pb2.ValidatorSet, _Mapping)]]=..., last_height_changed: _Optional[int]=...) -> None:
        ...

class Version(_message.Message):
    __slots__ = ['consensus', 'software']
    CONSENSUS_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_FIELD_NUMBER: _ClassVar[int]
    consensus: _types_pb2_1_1.Consensus
    software: str

    def __init__(self, consensus: _Optional[_Union[(_types_pb2_1_1.Consensus, _Mapping)]]=..., software: _Optional[str]=...) -> None:
        ...




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from .....ibc.core.channel.v1 import query_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_query__pb2

class QueryStub(object):
    'Query provides defines the gRPC querier service\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.Channel = channel.unary_unary('/ibc.core.channel.v1.Query/Channel', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelResponse.FromString)
        self.Channels = channel.unary_unary('/ibc.core.channel.v1.Query/Channels', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsResponse.FromString)
        self.ConnectionChannels = channel.unary_unary('/ibc.core.channel.v1.Query/ConnectionChannels', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsResponse.FromString)
        self.ChannelClientState = channel.unary_unary('/ibc.core.channel.v1.Query/ChannelClientState', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateResponse.FromString)
        self.ChannelConsensusState = channel.unary_unary('/ibc.core.channel.v1.Query/ChannelConsensusState', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateResponse.FromString)
        self.PacketCommitment = channel.unary_unary('/ibc.core.channel.v1.Query/PacketCommitment', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentResponse.FromString)
        self.PacketCommitments = channel.unary_unary('/ibc.core.channel.v1.Query/PacketCommitments', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsResponse.FromString)
        self.PacketReceipt = channel.unary_unary('/ibc.core.channel.v1.Query/PacketReceipt', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptResponse.FromString)
        self.PacketAcknowledgement = channel.unary_unary('/ibc.core.channel.v1.Query/PacketAcknowledgement', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementResponse.FromString)
        self.PacketAcknowledgements = channel.unary_unary('/ibc.core.channel.v1.Query/PacketAcknowledgements', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsResponse.FromString)
        self.UnreceivedPackets = channel.unary_unary('/ibc.core.channel.v1.Query/UnreceivedPackets', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsResponse.FromString)
        self.UnreceivedAcks = channel.unary_unary('/ibc.core.channel.v1.Query/UnreceivedAcks', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksResponse.FromString)
        self.NextSequenceReceive = channel.unary_unary('/ibc.core.channel.v1.Query/NextSequenceReceive', request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveRequest.SerializeToString, response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveResponse.FromString)

class QueryServicer(object):
    'Query provides defines the gRPC querier service\n    '

    def Channel(self, request, context):
        'Channel queries an IBC Channel.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Channels(self, request, context):
        'Channels queries all the IBC channels of a chain.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectionChannels(self, request, context):
        'ConnectionChannels queries all the channels associated with a connection\n        end.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelClientState(self, request, context):
        'ChannelClientState queries for the client state for the channel associated\n        with the provided channel identifiers.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelConsensusState(self, request, context):
        'ChannelConsensusState queries for the consensus state for the channel\n        associated with the provided channel identifiers.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PacketCommitment(self, request, context):
        'PacketCommitment queries a stored packet commitment hash.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PacketCommitments(self, request, context):
        'PacketCommitments returns all the packet commitments hashes associated\n        with a channel.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PacketReceipt(self, request, context):
        'PacketReceipt queries if a given packet sequence has been received on the\n        queried chain\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PacketAcknowledgement(self, request, context):
        'PacketAcknowledgement queries a stored packet acknowledgement hash.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PacketAcknowledgements(self, request, context):
        'PacketAcknowledgements returns all the packet acknowledgements associated\n        with a channel.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnreceivedPackets(self, request, context):
        'UnreceivedPackets returns all the unreceived IBC packets associated with a\n        channel and sequences.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnreceivedAcks(self, request, context):
        'UnreceivedAcks returns all the unreceived IBC acknowledgements associated\n        with a channel and sequences.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NextSequenceReceive(self, request, context):
        'NextSequenceReceive returns the next receive sequence for a given channel.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'Channel': grpc.unary_unary_rpc_method_handler(servicer.Channel, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelResponse.SerializeToString), 'Channels': grpc.unary_unary_rpc_method_handler(servicer.Channels, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsResponse.SerializeToString), 'ConnectionChannels': grpc.unary_unary_rpc_method_handler(servicer.ConnectionChannels, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsResponse.SerializeToString), 'ChannelClientState': grpc.unary_unary_rpc_method_handler(servicer.ChannelClientState, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateResponse.SerializeToString), 'ChannelConsensusState': grpc.unary_unary_rpc_method_handler(servicer.ChannelConsensusState, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateResponse.SerializeToString), 'PacketCommitment': grpc.unary_unary_rpc_method_handler(servicer.PacketCommitment, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentResponse.SerializeToString), 'PacketCommitments': grpc.unary_unary_rpc_method_handler(servicer.PacketCommitments, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsResponse.SerializeToString), 'PacketReceipt': grpc.unary_unary_rpc_method_handler(servicer.PacketReceipt, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptResponse.SerializeToString), 'PacketAcknowledgement': grpc.unary_unary_rpc_method_handler(servicer.PacketAcknowledgement, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementResponse.SerializeToString), 'PacketAcknowledgements': grpc.unary_unary_rpc_method_handler(servicer.PacketAcknowledgements, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsResponse.SerializeToString), 'UnreceivedPackets': grpc.unary_unary_rpc_method_handler(servicer.UnreceivedPackets, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsResponse.SerializeToString), 'UnreceivedAcks': grpc.unary_unary_rpc_method_handler(servicer.UnreceivedAcks, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksResponse.SerializeToString), 'NextSequenceReceive': grpc.unary_unary_rpc_method_handler(servicer.NextSequenceReceive, request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveRequest.FromString, response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('ibc.core.channel.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query provides defines the gRPC querier service\n    '

    @staticmethod
    def Channel(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/Channel', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Channels(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/Channels', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConnectionChannels(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/ConnectionChannels', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryConnectionChannelsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChannelClientState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/ChannelClientState', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelClientStateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChannelConsensusState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/ChannelConsensusState', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryChannelConsensusStateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PacketCommitment(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/PacketCommitment', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PacketCommitments(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/PacketCommitments', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketCommitmentsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PacketReceipt(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/PacketReceipt', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketReceiptResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PacketAcknowledgement(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/PacketAcknowledgement', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PacketAcknowledgements(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/PacketAcknowledgements', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryPacketAcknowledgementsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnreceivedPackets(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/UnreceivedPackets', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedPacketsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnreceivedAcks(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/UnreceivedAcks', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryUnreceivedAcksResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NextSequenceReceive(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Query/NextSequenceReceive', ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveRequest.SerializeToString, ibc_dot_core_dot_channel_dot_v1_dot_query__pb2.QueryNextSequenceReceiveResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class MsgAllocateRequest(_message.Message):
    __slots__ = ['address', 'bytes', 'frm', 'id']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    bytes: str
    frm: str
    id: int

    def __init__(self, frm: _Optional[str]=..., id: _Optional[int]=..., address: _Optional[str]=..., bytes: _Optional[str]=...) -> None:
        ...

class MsgAllocateResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class MsgCancelRequest(_message.Message):
    __slots__ = ['frm', 'id']
    FRM_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    frm: str
    id: int

    def __init__(self, frm: _Optional[str]=..., id: _Optional[int]=...) -> None:
        ...

class MsgCancelResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...
